yt package
==========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   yt.data_objects
   yt.extensions
   yt.fields
   yt.frontends
   yt.geometry
   yt.sample_data
   yt.units
   yt.utilities
   yt.visualization

Submodules
----------

.. toctree::
   :maxdepth: 4

   yt.api
   yt.arraytypes
   yt.config
   yt.convenience
   yt.exthook
   yt.funcs
   yt.loaders
   yt.mods
   yt.startup_tasks
   yt.testing

Module contents
---------------

.. automodule:: yt
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
